==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_en.lua <==

dialogId("d1-z-b1", "", "")

dialogId("d1-z-b2", "", "")

dialogId("d1-z-b3", "", "")

dialogId("d1-z-p1", "", "")

dialogId("d1-z-p2", "", "")

dialogId("d1-z-v0", "", "")

dialogId("d1-z-v1", "", "")

dialogId("d1-z-v2", "", "")

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")

dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")

dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")

dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")

dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")

dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")

dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")

dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")

dialogId("d1-2-brb0", "font_viking2", "Oh, no!")

dialogId("d1-2-brb1", "font_viking2", "Again?")

dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")

dialogId("d1-3-brb0", "font_viking3", "What happened?")

dialogId("d1-3-brb1", "font_viking3", "Again?")

dialogId("d1-3-brb2", "font_viking3", "Oh, no!")

dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")

dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")

dialogId("d1-4-brb2", "font_viking4", "How could it be?")

dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")

dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")

dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_en.lua <==

dialogId("d1-z-b1", "", "")

dialogId("d1-z-b2", "", "")

dialogId("d1-z-b3", "", "")

dialogId("d1-z-p1", "", "")

dialogId("d1-z-p2", "", "")

dialogId("d1-z-v0", "", "")

dialogId("d1-z-v1", "", "")

dialogId("d1-z-v2", "", "")

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")

dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")

dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")

dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")

dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")

dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")

dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")

dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")

dialogId("d1-2-brb0", "font_viking2", "Oh, no!")

dialogId("d1-2-brb1", "font_viking2", "Again?")

dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")

dialogId("d1-3-brb0", "font_viking3", "What happened?")

dialogId("d1-3-brb1", "font_viking3", "Again?")

dialogId("d1-3-brb2", "font_viking3", "Oh, no!")

dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")

dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")

dialogId("d1-4-brb2", "font_viking4", "How could it be?")

dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")

dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")

dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
